/**
 * External dependencies
 */
import { expect } from 'chai';

/**
 * Internal dependencies
 */
import { planLevelsMatch } from '..';
import {
	PLAN_BUSINESS_MONTHLY,
	PLAN_BUSINESS,
	PLAN_BUSINESS_2_YEARS,
	PLAN_FREE,
	PLAN_JETPACK_BUSINESS,
	PLAN_JETPACK_BUSINESS_MONTHLY,
	PLAN_JETPACK_FREE,
	PLAN_JETPACK_PERSONAL,
	PLAN_JETPACK_PERSONAL_MONTHLY,
	PLAN_JETPACK_PREMIUM,
	PLAN_JETPACK_PREMIUM_MONTHLY,
	PLAN_PERSONAL,
	PLAN_PERSONAL_2_YEARS,
	PLAN_BLOGGER,
	PLAN_BLOGGER_2_YEARS,
	PLAN_PREMIUM,
	PLAN_PREMIUM_2_YEARS,
} from '../constants';

describe( 'planLevelsMatch', () => {
	const testPlansArrayIndependentOfOrder = ( plansArray, result ) =>
		plansArray.forEach( ( [ slugA, slugB ] ) => {
			expect( planLevelsMatch( slugA, slugB ) ).to.be[ result ];
			expect( planLevelsMatch( slugB, slugA ) ).to.be[ result ];
		} );

	test( 'should return true for identical plans', () => {
		const identicalPlans = [
			[ PLAN_BUSINESS_MONTHLY, PLAN_BUSINESS_MONTHLY ],
			[ PLAN_BUSINESS, PLAN_BUSINESS ],
			[ PLAN_BUSINESS_2_YEARS, PLAN_BUSINESS_2_YEARS ],
			[ PLAN_FREE, PLAN_FREE ],
			[ PLAN_JETPACK_BUSINESS, PLAN_JETPACK_BUSINESS ],
			[ PLAN_JETPACK_BUSINESS_MONTHLY, PLAN_JETPACK_BUSINESS_MONTHLY ],
			[ PLAN_JETPACK_FREE, PLAN_JETPACK_FREE ],
			[ PLAN_JETPACK_PERSONAL, PLAN_JETPACK_PERSONAL ],
			[ PLAN_JETPACK_PERSONAL_MONTHLY, PLAN_JETPACK_PERSONAL_MONTHLY ],
			[ PLAN_JETPACK_PREMIUM, PLAN_JETPACK_PREMIUM ],
			[ PLAN_JETPACK_PREMIUM_MONTHLY, PLAN_JETPACK_PREMIUM_MONTHLY ],
			[ PLAN_PERSONAL, PLAN_PERSONAL ],
			[ PLAN_PERSONAL_2_YEARS, PLAN_PERSONAL_2_YEARS ],
			[ PLAN_BLOGGER, PLAN_BLOGGER ],
			[ PLAN_BLOGGER_2_YEARS, PLAN_BLOGGER_2_YEARS ],
			[ PLAN_PREMIUM, PLAN_PREMIUM ],
			[ PLAN_PREMIUM_2_YEARS, PLAN_PREMIUM_2_YEARS ],
		];
		testPlansArrayIndependentOfOrder( identicalPlans, 'true' );
	} );

	test( 'should return true for matching plans', () => {
		const matchingPlans = [
			[ PLAN_BUSINESS_MONTHLY, PLAN_BUSINESS ],
			[ PLAN_JETPACK_BUSINESS, PLAN_JETPACK_BUSINESS_MONTHLY ],
			[ PLAN_JETPACK_PERSONAL, PLAN_JETPACK_PERSONAL_MONTHLY ],
			[ PLAN_JETPACK_PREMIUM, PLAN_JETPACK_PREMIUM_MONTHLY ],
		];
		testPlansArrayIndependentOfOrder( matchingPlans, 'true' );
	} );

	test( 'should return false for non-matching plans', () => {
		const nonMatchingPlans = [
			[ PLAN_JETPACK_BUSINESS, PLAN_BUSINESS ],
			[ PLAN_JETPACK_BUSINESS, PLAN_BUSINESS_2_YEARS ],
			[ PLAN_JETPACK_BUSINESS, PLAN_FREE ],
			[ PLAN_JETPACK_BUSINESS_MONTHLY, PLAN_BUSINESS_MONTHLY ],
			[ PLAN_JETPACK_BUSINESS, PLAN_JETPACK_PERSONAL_MONTHLY ],
			[ PLAN_JETPACK_BUSINESS, PLAN_JETPACK_PREMIUM_MONTHLY ],
			[ PLAN_JETPACK_BUSINESS, PLAN_PERSONAL ],
			[ PLAN_JETPACK_BUSINESS, PLAN_PERSONAL_2_YEARS ],
			[ PLAN_JETPACK_BUSINESS, PLAN_PREMIUM_2_YEARS ],
			[ PLAN_JETPACK_BUSINESS, PLAN_PREMIUM ],
			[ PLAN_JETPACK_PERSONAL, PLAN_BUSINESS ],
			[ PLAN_JETPACK_PERSONAL, PLAN_FREE ],
			[ PLAN_JETPACK_PERSONAL, PLAN_JETPACK_BUSINESS_MONTHLY ],
			[ PLAN_JETPACK_PERSONAL, PLAN_JETPACK_PREMIUM_MONTHLY ],
			[ PLAN_JETPACK_PERSONAL, PLAN_PERSONAL ],
			[ PLAN_JETPACK_PERSONAL, PLAN_PERSONAL_2_YEARS ],
			[ PLAN_JETPACK_PERSONAL, PLAN_PREMIUM ],
			[ PLAN_JETPACK_PERSONAL, PLAN_PREMIUM_2_YEARS ],
			[ PLAN_JETPACK_PERSONAL, PLAN_BLOGGER ],
			[ PLAN_JETPACK_PERSONAL, PLAN_BLOGGER_2_YEARS ],
			[ PLAN_JETPACK_PREMIUM, PLAN_BUSINESS ],
			[ PLAN_JETPACK_PREMIUM, PLAN_FREE ],
			[ PLAN_JETPACK_PREMIUM, PLAN_JETPACK_BUSINESS_MONTHLY ],
			[ PLAN_JETPACK_PREMIUM, PLAN_JETPACK_PERSONAL_MONTHLY ],
			[ PLAN_JETPACK_PREMIUM, PLAN_PERSONAL ],
			[ PLAN_JETPACK_PREMIUM, PLAN_PERSONAL_2_YEARS ],
			[ PLAN_JETPACK_PREMIUM, PLAN_BLOGGER ],
			[ PLAN_JETPACK_PREMIUM, PLAN_BLOGGER_2_YEARS ],
			[ PLAN_JETPACK_PREMIUM, PLAN_PREMIUM ],
			[ PLAN_JETPACK_PREMIUM, PLAN_PREMIUM_2_YEARS ],
		];
		testPlansArrayIndependentOfOrder( nonMatchingPlans, 'false' );
	} );
} );
